@@ -15,13 +15,11 @@ use parent 'TestBase';
 
 use Test::More;
 
-use MockCpsrvd::cpanel;
-
 use constant _CP_REQUIRE => (
     [ 'HTTP::Message' => 6.07 ],
     'HTTP::Request',
     'HTTP::Response',
-    'IO::Socket::SSL',
+    'MockCpsrvd::cpanel',
 );
 
 sub TRANSPORT {
